Skip to main contentCrate graphix_package
Source - GraphixPM
- The Graphix package manager
- IndexSet
- A hash set where the iteration order of the values is independent of their
hash values.
- MainThreadHandle
- Handle to run a closure on the main thread
- PackageId
- PackageEntry
- A package entry in packages.toml — either a version string or a path.
- CustomDisplay
- Trait implemented by custom Graphix displays, e.g. TUIs, GUIs, etc.
- Package
- Trait implemented by Graphix packages
- create_package
- Create a new graphix package